==> Paws-0.01.tar.gz: Paws-0.01/lib/Paws/CloudTrail/StartLogging.pm <==

package Paws::CloudTrail::StartLogging {
  use Moose;
  has Name => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'StartLogging');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::CloudTrail::StartLoggingResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
}
1;

### main pod documentation begin ###

=head1 NAME

Paws::CloudTrail::StartLogging - Arguments for method StartLogging on Paws::CloudTrail

=head1 DESCRIPTION

This class represents the parameters used for calling the method StartLogging on the 
AWS CloudTrail service. Use the attributes of this class
as arguments to method StartLogging.

You shouln't make instances of this class. Each attribute should be used as a named argument in the call to StartLogging.

As an example:

  $service_obj->StartLogging(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES

=head2 B<REQUIRED> Name => Str

  

The name of the trail for which CloudTrail logs AWS API calls.












=head1 SEE ALSO

This class forms part of L<Paws>, and documents parameters for StartLogging in Paws::CloudTrail

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.04.tar.gz: Paws-0.04/lib/Paws/CloudTrail/StartLogging.pm <==

package Paws::CloudTrail::StartLogging {
  use Moose;
  has Name => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'StartLogging');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::CloudTrail::StartLoggingResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
}
1;

### main pod documentation begin ###

=head1 NAME

Paws::CloudTrail::StartLogging - Arguments for method StartLogging on Paws::CloudTrail

=head1 DESCRIPTION

This class represents the parameters used for calling the method StartLogging on the 
AWS CloudTrail service. Use the attributes of this class
as arguments to method StartLogging.

You shouln't make instances of this class. Each attribute should be used as a named argument in the call to StartLogging.

As an example:

  $service_obj->StartLogging(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES

=head2 B<REQUIRED> Name => Str

  

The name of the trail for which CloudTrail logs AWS API calls.












=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method StartLogging in L<Paws::CloudTrail>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut
